fn func_members(
func: &Function<'_>,
custom_type: &[Symbol],
) -> Option<DynSolType>Expand description
Returns Some if the custom type is a function member access.
Ref: https://docs.soliditylang.org/en/latest/types.html#function-types
fn func_members(
func: &Function<'_>,
custom_type: &[Symbol],
) -> Option<DynSolType>Returns Some if the custom type is a function member access.
Ref: https://docs.soliditylang.org/en/latest/types.html#function-types